@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.15 1999/07/10 13:23:09 bazsi Exp $ */
+ * $Id: io.c,v 1.16 1999/08/04 21:31:03 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -233,7 +233,7 @@ closes
 				else if (fd->want_write && fd->write)
 					WRITE_FD(fd);
 				else {
-					werror("io_iter(): POLLHUP on inactive fd!\n");
+					verbose("io_iter(): POLLHUP on inactive fd!\n");
 					closekill_fd(fd, CLOSE_EOF);
 				}
 				continue;
@@ -272,7 +272,7 @@ closes
 		}
 	}
 	if (!nfds && !nco) {
-		werror("io_iter(): no waiting fds and no callouts! exiting...\n");
+		verbose("io_iter(): no waiting fds and no callouts! exiting...\n");
 		return 0;
 	}
 	return 1;
