@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: pkt_buffer.c,v 1.6 1999/05/29 13:57:30 bazsi Exp $
+ * $Id: pkt_buffer.c,v 1.7 1999/07/10 13:23:09 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -64,6 +64,8 @@ static int do_write_str(struct abstract_write *c, struct ol_string *string)
 {
 	CAST(pkt_buffer, self, c);
 	
+	if (self->super.closed)
+		return ST_FAIL | ST_CLOSE;
 	if (self->queue_size == self->queue_max) {
 		/* fifo full */
 		ol_string_free(string);
